---
permalink: /acks/
layout: single
title: "Acknowledgements"
excerpt: "List of public and private organizations that have contributed to the development of GNSS-SDR."
sidebar:
    nav: "about"
last_modified_at: 2021-05-10T14:38:52+02:00
---

This project has been mainly developed on a volunteer basis, for education and
research purposes. The main [Developer Team]({{ "/team/" | relative_url }}) is a
group of researchers at [CTTC](https://www.cttc.cat/), a non-profit research
institution, and the project enjoys from a solid base of external users and
contributors.

Slowly but steadily baked, the source code evolved and demonstrated its
feasibility as an open and free framework for software-defined GNSS receiver
development, attracting the interest of [more researchers]({{ "/publications/" |
relative_url }}), students, skilled hobbyists, and the industry.

According to [Black Duck Open Hub](https://www.openhub.net/p/gnss-sdr), the
development of GNSS-SDR from its [first
commit](https://github.com/gnss-sdr/gnss-sdr/commit/228fa3b797dba7d0192f751e7e25a7b8348f9326)
to a Git repository (in October 2011, after a happy childhood living in a
Subversion repository) up to now has taken 77 years of effort, as estimated by
the Constructive Cost Model ([COCOMO](https://en.wikipedia.org/wiki/COCOMO)).
{: .notice--info}

The Authors are proud to be supported by the following public institutions,
private companies, and spontaneous, enthusiastic volunteers that contribute to
maintaining and expanding the capabilities and field of applications of a free
and open-source GNSS software-defined receiver:


## Public Research Funds

* Support from the Spanish Ministry of Science, Innovation, and Universities.

  ![ARISTIDES logo]({{ "/assets/images/logo-aristides.png" | relative_url }}){:width="400px" .invert-colors}
  {: style="text-align: center;"}

  **The Spanish Ministry of Science, Innovation, and Universities** provides
  partial support for development infrastructure through the [Statistical
  Learning and Inference for Large Dimensional Communication Systems
  (ARISTIDES)](https://www.cttc.cat/project/aprendizaje-estadistico-e-inferencia-para-sistemas-de-comunicacion-de-alta-dimensionalidad/)
  project (RTI2018-099722-B-I00). Jan. 2019 - Dec. 2021.
  {: .notice--success}

* Support from the European Union through European Regional Development Fund (ERDF).

  ![ERDF logo]({{ "/assets/images/logo-eu.png" | relative_url }}){:width="215px"} ![ERDF logo]({{ "/assets/images/logo-feder.png" | relative_url }}){:width="300px"}
  {: style="text-align: center;"}

  GNSS-SDR Continuous Integration system is run in a hardware infrastructure
  (servers, network storage) partially provided by ERDF through Project 5G-Lab
  (Spanish Ministry of Science, Innovation, and Universities, Ref.
  EQC2018-005257-P). Nov. 2018 - Mar. 2021.
  {: .notice--success}

* Support of Research Groups by the Government of Catalonia.

  **The Government of Catalonia**, through Grant 2017--SGR--1479, provides
  partial support for registrations and travel expenses to well-established
  scientific conferences. Sep. 2017 - Sep. 2021.
  {: .notice--success}

* **[AUDITOR](https://www.euspa.europa.eu/advanced-multi-constellation-egnss-augmentation-and-monitoring-network-and-its-application-precision) - Advanced Multi-Constellation EGNSS Augmentation and Monitoring Network and its Application in Precision Agriculture**
  is a project that developed a multi-band, multi-constellation receiver based on
  GNSS-SDR and targeted to Precision Agriculture applications, targeting Galileo
  and GPS civil signals in the L1, L2, and L5 bands.

  ![AUDITOR logo]({{ "/assets/images/logo-auditor.png" | relative_url }}){:height="250px" width="250px"}
  {: style="text-align: center;"}

  This project received funding from the [**European Union Agency for the Space
  Programme**](https://www.euspa.europa.eu/) (formerly called GSA) under the
  European Union's Horizon 2020 research and innovation programme under grant
  agreement no. [687367](https://cordis.europa.eu/project/id/687367).
  Jan. 2016 - Jun. 2018.
  {: .notice--success}

* Support from the Spanish Ministry of Economy and Competitiveness.

  **The Spanish Ministry of Economy and Competitiveness**, through project
  ADVENTURE (Ref. TEC2015-69868-C2-2-R), provided partial support for
  registrations and travel expenses to well-established scientific
  conferences, as well as publication fees. Jan. 2016 - Jan. 2019.
  {: .notice--success}

* Research networks

  - **COST Action CA15104 - Inclusive Radio Communication Networks for 5G and beyond ([IRACON](http://www.iracon.org/))**, aimed to achieve scientific breakthroughs by introducing novel design and analysis methods for the 5th-generation (5G) and beyond-5G radio communication networks.

  ![IRACON logo]({{ "/assets/images/iracon-logo-big.jpg" | relative_url }}){:height="250px" width="250px"}
  {: style="text-align: center;"}

  **IRACON** offered Short Term Scientific Missions grants for exchange visits aimed at supporting individual mobility, strengthening existing networks and fostering collaboration between researchers. Check out the [application procedure](http://www.iracon.org/stsms/). Mar 2016 - Mar. 2020.
  {: .notice--success}


## Education programs funded by private entities

* **Google Summer of Code (GSoC)**

    ![GSoC logo]({{ "/assets/images/logo-gsoc.png" | relative_url }}){:height="100px" width="100px"}
    {: style="text-align: center;"}

[2020](https://summerofcode.withgoogle.com/archive/2020/organizations/5600351610208256/)

  * Project: [Expanding the GNSS receiver to Galileo E5b signals](https://summerofcode.withgoogle.com/archive/2020/projects/6254817149714432/), by Piyush Gupta.
  * Project: [Robust Interference Mitigation for anti-jamming](https://summerofcode.withgoogle.com/archive/2020/projects/5671680850001920/), by Haoqing Li.    

[2019](https://summerofcode.withgoogle.com/archive/2019/organizations/6369884148072448/)

  * Project: [Expanding the receiver to BEIDOU B1C](https://summerofcode.withgoogle.com/archive/2019/projects/6509812521631744/), by Andrew Kamble.
  * Project: [Nonlinear State Estimation for Carrier Synchronization in GNSS-SDR](https://summerofcode.withgoogle.com/archive/2019/projects/6299766860808192/), by Gerald LaMountain.
  * Project: [Optimal Frame Synchronization Detection](https://summerofcode.withgoogle.com/archive/2019/projects/5062110764072960/), by Lucas Ventura.

[2018](https://summerofcode.withgoogle.com/archive/2018/organizations/5951344653369344/)

  * Project: [Acquisition and Tracking GNU Radio blocks for different data types](https://summerofcode.withgoogle.com/projects/#5284171652530176), by Adri&aacute;n P&eacute;rez.
  * Project: [Design and Implementation of a Graphical User Interface (GUI) to show the GNSS-SDR status in real-time](https://summerofcode.withgoogle.com/archive/2018/projects/6562581313486848/), by &Aacute;lvaro Cebri&aacute;n Juan.
  * Project: [Expanding the receiver to BeiDou B1I](https://summerofcode.withgoogle.com/archive/2018/projects/5965667966648320/), by Sergi Segura Mu&ntilde;oz.
  * Project: [Expanding the receiver to BeiDou B1I](https://summerofcode.withgoogle.com/archive/2018/projects/5089211505967104/), by Sara Hrbek.
  * Project: [Expanding the receiver to Beidou B2a](https://summerofcode.withgoogle.com/archive/2018/projects/6197114962968576/), by Dong-Kyeong Lee.
  * Project: [Optimum frame synchronization project](https://summerofcode.withgoogle.com/projects/#5051576423546880), by Mustafa Abaas.
  * Project: [Proposal to implement Bayesian Covariance Estimation for Kalman Filter based Digital Carrier Synchronization in GNSS-SDR](https://summerofcode.withgoogle.com/archive/2018/projects/6167449959399424/), by Gerald LaMountain.

[2017](https://summerofcode.withgoogle.com/archive/2017/organizations/5204929132101632/)

  * In [Robust KF-based Tracking Techniques for Advanced GNSS Receivers](https://summerofcode.withgoogle.com/archive/2017/projects/6261573228167168/) Shashanka Joisa worked on improving the tracking loops.
  * In [Graphical User Interface for GNSS-SDR configuration](https://summerofcode.withgoogle.com/archive/2017/projects/6610212098146304/), Usman Haider worked on a GUI for making GNSS-SDR configuration easier and more intuitive.
  * In [Expanding the receiver to GLONASS](https://summerofcode.withgoogle.com/archive/2017/projects/6138210627354624/), Damian Miralles worked on expanding GNSS-SDR to GLONASS signals.
  * In [Expanding the GNSS-SDR receiver to GLONASS](https://summerofcode.withgoogle.com/archive/2017/projects/5357969688494080/), Gabriel Araujo worked on expanding GNSS-SDR to GLONASS signals.
  * In [Pulsed and continuous wave radio frequency interferences mitigation: application to GNSS-SDR in low Signal to Noise ratio scenarios](https://summerofcode.withgoogle.com/archive/2017/projects/5347588081451008/), Antonio Ramos de Torres worked on interference mitigation techniques.

[2016](https://summerofcode.withgoogle.com/archive/2016/organizations/5800194151022592/)

  * In [GNSS-SDR port to android](https://summerofcode.withgoogle.com/projects/?sp-page=2#4871316700135424), Eric Wild worked on porting GNSS-SDR to Android.
  * In [Implementation of the BeiDou signal tracking block for the GNSS-SDR Project](https://summerofcode.withgoogle.com/projects/?sp-page=2#5537250955755520), Enric Juan developed part of the Beidou B1 receiver.
  * In [Project Frisbee : An Antenna Array Receiver Testbed for GNSS-SDR](https://summerofcode.withgoogle.com/projects/?sp-page=2#4771132842442752), Ajith Peter explored advanced front-end architectures and evolved his open design.

[2015](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr)

  * In [BeiDou signal generation and acquisition](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr/projects/giorgio.html), Giorgio Savastano explored acquisition methods for the Beidou B1 receiver.
  * In [Development of a Low Cost Multi-Constellation GNSS Sampler](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr/projects/ajithpeter.html), Ajith Peter implemented the first version of a low-cost radiofrequency front-end, achieving a working prototype.
  * In [Embedding GNSS-SDR in a System on Chip](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr/projects/cris_proteinlab.html), Cristian Becerra worked in adapting GNSS-SDR to embedded devices.
  * In [GNSSSDR Metadata Standard Implementation - Automatic Receiver Configuration](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr/projects/sumitgautamjbp.html), Sumit Gautam explored novel interfaces and APIs to describe signal inputs.
  * In [Run-time partitioning of functions at an embedded SDR framework](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr/projects/scaelles.html), Sergi Caelles worked in adapting GNSS-SDR to embedded devices.
  * In [Run-time partitioning of SDR functions featuring hardware accelerators](https://www.google-melange.com/archive/gsoc/2015/orgs/gnss_sdr/projects/paul_jsd.html), Paul Harbanau worked on run-time partitioning strategies in FPGA devices.

[2014](https://www.google-melange.com/archive/gsoc/2014/orgs/gnss_sdr)

  * In [Development of a GNSS Sampler using the MAX2769 Universal GPS Receiver](https://www.google-melange.com/archive/gsoc/2014/orgs/gnss_sdr/projects/ajithpeter.html), Ajith Peter worked on the design of a low-cost radiofrequency front-end for GNSS-SDR.
  * In [Expanding the receiver to Galileo E5a](https://www.google-melange.com/archive/gsoc/2014/orgs/gnss_sdr/projects/marc_sales.html), Marc Sales pioneered the development of blocks for the Galileo E5a receiver.
  * In [Faster GNSS Signal Acquisition using the Sparse Fourier Transform](https://www.google-melange.com/archive/gsoc/2014/orgs/gnss_sdr/projects/dmiralles2009.html), Damian Miralles explored the QuickSync algorithm for signal acquisition.
  * In [New blocks for BeiDou B1 in GNSS-SDR: toward a multi-constellation receiver](https://www.google-melange.com/archive/gsoc/2014/orgs/gnss_sdr/projects/marabra87.html), Mara Branzanti started working on the Beidou B1 receiver.

[2013](https://www.google-melange.com/archive/gsoc/2013/orgs/gnss_sdr)

  * In [Development of new blocks for Galileo E1 in GNSS-SDR: From telemetry to PVT solutions](https://www.google-melange.com/archive/gsoc/2013/orgs/gnss_sdr/projects/marabra87.html), Mara Branzanti worked on the Galileo E1 receiver.
  * In [GNSS-SDR goes SBAS](https://www.google-melange.com/archive/gsoc/2013/orgs/gnss_sdr/projects/fehrdan.html), Daniel Fehr set the basis for the EGNOS receiver.
  * In [Improve the acquisition sensitivity of a GNSS receiver](https://www.google-melange.com/archive/gsoc/2013/orgs/gnss_sdr/projects/marcmolina.html), Marc Molina improved the performance of acquisition algorithms.

[2012](https://www.google-melange.com/archive/gsoc/2012/orgs/gnu), under the kind umbrella of GNU Radio and the GNU Project.

  * In [GNSS Receiver on GNU Radio](https://www.google-melange.com/archive/gsoc/2012/orgs/gnu/projects/lesteve.html), Luis Esteve implemented an acquisition algorithm for GPS L1 C/A.

    **Google**, through the GSoC program, offers students a stipend for contributing to open source projects.
    {: .notice--success}


* **ESA Summer Of Code In Space (SOCIS)**

  * **2019**
    - In _Improving the Graphical User Interface (GUI) for monitoring the GNSS-SDR status in real-time_, 	&Aacute;lvaro Cebri&aacute;n worked in a GUI for GNSS-SDR (Honorable Participation).

  * **2015**
    - In _Direct Position Estimation_, Luis Esteve explored the DPE algorithm and proposed receiver architectures.

  * **2014**
    - In _GNSS-SDR. Acceleration with VOLK_, Andr&eacute;s Cecilia created a new VOLK module with kernels for GNSS signal processing, the inception of the current [VOLK_GNSSSDR](https://github.com/gnss-sdr/gnss-sdr/tree/main/src/algorithms/libs/volk_gnsssdr_module/volk_gnsssdr).

  * **2013**
    - In _Real-time positioning solution for GNSS-SDR_, Vladimir Avrov started working on the generation of RTCM messages.

    **The European Space Agency**, through the
    [SOCIS](https://www.esa.int/Enabling_Support/Space_Engineering_Technology/SOCIS_The_ESA_Summer_of_Code_in_Space)
    program, offers students a stipend for contributing to open source
    projects.
    {: .notice--success}

